
<!-- README.md is generated from README.Rmd. Please edit that file -->

# ggsci <img src="man/figures/logo.png" align="right" width="120" />

<!-- badges: start -->

[![R-CMD-check](https://github.com/nanxstats/ggsci/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/nanxstats/ggsci/actions/workflows/R-CMD-check.yaml)
[![CRAN
Version](https://www.r-pkg.org/badges/version/ggsci)](https://cran.r-project.org/package=ggsci)
[![Downloads from the RStudio CRAN
mirror](https://cranlogs.r-pkg.org/badges/ggsci)](https://cran.r-project.org/package=ggsci)
<!-- badges: end -->

ggsci offers a collection of ggplot2 color palettes inspired by
scientific journals, data visualization libraries, science fiction
movies, and TV shows.

## Installation

You can install ggsci from CRAN:

``` r
install.packages("ggsci")
```

Or try the development version on GitHub:

``` r
remotes::install_github("nanxstats/ggsci")
```

[Browse the vignette](https://nanx.me/ggsci/articles/ggsci.html) (or
open with `vignette("ggsci")` in R) for a quick-start guide.

## Gallery

### NPG

<img src="man/figures/README-ggsci-npg-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### AAAS

<img src="man/figures/README-ggsci-aaas-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### NEJM

<img src="man/figures/README-ggsci-nejm-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Lancet

<img src="man/figures/README-ggsci-lancet-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### JAMA

<img src="man/figures/README-ggsci-jama-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### BMJ

<img src="man/figures/README-ggsci-bmj-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### JCO

<img src="man/figures/README-ggsci-jco-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### UCSCGB

<img src="man/figures/README-ggsci-ucscgb-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### D3

<img src="man/figures/README-ggsci-d3-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Gephi

<img src="man/figures/README-ggsci-gephi-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Observable

<img src="man/figures/README-ggsci-observable-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Primer

<img src="man/figures/README-ggsci-primer-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Atlassian

<img src="man/figures/README-ggsci-atlassian-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### iTerm

<img src="man/figures/README-ggsci-iterm-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### LocusZoom

<img src="man/figures/README-ggsci-locuszoom-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### IGV

<img src="man/figures/README-ggsci-igv-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### COSMIC

<img src="man/figures/README-ggsci-cosmic-1.png" alt="" width="100%" style="display: block; margin: auto;" /><img src="man/figures/README-ggsci-cosmic-2.png" alt="" width="100%" style="display: block; margin: auto;" /><img src="man/figures/README-ggsci-cosmic-3.png" alt="" width="100%" style="display: block; margin: auto;" />

### UChicago

<img src="man/figures/README-ggsci-uchicago-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Star Trek

<img src="man/figures/README-ggsci-startrek-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Tron Legacy

<img src="man/figures/README-ggsci-tron-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Futurama

<img src="man/figures/README-ggsci-futurama-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Rick and Morty

<img src="man/figures/README-ggsci-rickandmorty-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### The Simpsons

<img src="man/figures/README-ggsci-simpsons-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Flat UI

<img src="man/figures/README-ggsci-flatui-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Frontiers

<img src="man/figures/README-ggsci-frontiers-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### GSEA

<img src="man/figures/README-ggsci-gsea-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Bootstrap 5

<img src="man/figures/README-ggsci-bs5-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Material Design

<img src="man/figures/README-ggsci-material-1.png" alt="" width="100%" style="display: block; margin: auto;" />

### Tailwind CSS

<img src="man/figures/README-ggsci-tw3-1.png" alt="" width="100%" style="display: block; margin: auto;" />

## Contribute

To contribute to this project, please take a look at the [Contributing
Guidelines](https://nanx.me/ggsci/CONTRIBUTING.html) first. Please note
that the ggsci project is released with a [Contributor Code of
Conduct](https://nanx.me/ggsci/CODE_OF_CONDUCT.html). By contributing to
this project, you agree to abide by its terms.
