#' Scientific Journal and Sci-Fi Themed Color Palettes for 'ggplot2'
#'
#' Scientific Journal and Sci-Fi Themed Color Palettes for 'ggplot2'
#'
#' Opened the vignette via \code{vignette("ggsci")}.
#'
#' \tabular{ll}{ Package: \tab ggsci\cr
#' Type: \tab Package\cr
#' License: \tab GPL-3\cr }
#'
#' @name ggsci-package
#' @docType package
#' @author Nan Xiao <\email{me@@nanx.me}>
#'         Miaozhu Li <\email{miaozhu.li@@duke.edu}>
NULL
