% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/discrete-ucscgb.R
\name{scale_color_ucscgb}
\alias{scale_color_ucscgb}
\alias{scale_colour_ucscgb}
\alias{scale_fill_ucscgb}
\title{UCSC Genome Browser color scales}
\usage{
scale_color_ucscgb(palette = c("default"), alpha = 1, ...)

scale_colour_ucscgb(palette = c("default"), alpha = 1, ...)

scale_fill_ucscgb(palette = c("default"), alpha = 1, ...)
}
\arguments{
\item{palette}{Palette type.
Currently there is one available option: \code{"default"}
(26-color palette).}

\item{alpha}{Transparency level, a real number in (0, 1].
See \code{alpha} in \code{\link[grDevices:rgb]{grDevices::rgb()}} for details.}

\item{...}{Additional parameters for \code{\link[ggplot2:discrete_scale]{ggplot2::discrete_scale()}}.}
}
\description{
See \code{\link[=pal_ucscgb]{pal_ucscgb()}} for details.
}
\examples{
example_scatterplot() + scale_color_ucscgb()
example_barplot() + scale_fill_ucscgb()
}
\author{
Nan Xiao | \email{me@nanx.me} | \url{https://nanx.me}
}
